@@ -8,7 +8,7 @@ use POSIX;
 use RSAT::GenericObject;
 use RSAT::message;
 use RSAT::error;
-use RSAT::email;
+#use RSAT::email;
 @ISA = qw( RSAT::GenericObject );
 
 =pod
@@ -46,6 +46,9 @@ sub IsNatural {
     }
 }
 
+
+
+
 ################################################################
 
 =pod
@@ -1151,7 +1154,6 @@ sub doit {
       $qsub_command .= " -e ".$job_file.".err";   ## STDER log file
       $qsub_command .= " -o ".$job_file.".log";   ## STDOUR log file
       $qsub_command .= " ".$job_file;             ## Script
-
       &RSAT::message::Debug("qsub command for torque", $qsub_command) if ($main::verbose >= 2);
 
     } elsif (lc($queue_manager) eq "sge") {
@@ -1184,7 +1186,6 @@ sub doit {
     ## Verbose: report command
     &RSAT::message::TimeWarn("Working dir", $wd) if ($verbose >= 4);
     &RSAT::message::TimeWarn(&hide_RSAT_path($command))  if ($verbose >= 3);
-
     ## Send the command to the queue
     unless ($dry) {
 #	&RSAT::message::Debug("Running command", $command) if ($main::verbose >= 3);
@@ -1206,7 +1207,6 @@ sub doit {
 	    print $err_handle "\n\n", $error_message, "\n";
 	  }
 	}
-
 	## Die if requested
 	if ($die_on_error) {
 	  &RSAT::error::FatalError($error_message);
@@ -1483,6 +1483,8 @@ sub sort_unique {
     return(@sorted_list);
 }
 
+
+
 1;
 
 __END__
